@@ -1,5 +1,5 @@
 """Logging definitions."""
 from sphinx.util.logging import getLogger
 
-logger = getLogger('sphinx_codeautolink')
-warn_type = 'codeautolink'
+logger = getLogger("sphinx_codeautolink")
+warn_type = "codeautolink"
